Crate credentialhelper

Crate credentialhelper 

Structs

Client
GetCredentialsRequest
GetCredentialsRequest represents the request for the get command of the Helper Protocol.
GetCredentialsResponse
GetCredentialsResponse represents the response for the get command of the Helper Protocol.

Traits

CredentialHelper
Represents a Credential Helper.